# radical.analytics

[RADICAL-Anlytics](https://github.com/radical-cybertools/radical.analytics) is a library supporting the analysis of data produced by the [RADICAL-Cybertools](https://radical-cybertools.github.io/). Currently, RADICAL-Analytics supports the [RADICAL-Pilot](https://github.com/radical-cybertools/radical.pilot) cybertool, and it has been used to support and develop the experimental analysis [published](http://radical.rutgers.edu/publications/) by the [RADICAL Group](http://radical.rutgers.edu/) at Rutgers University.

* Documentation: 
* API: https://github.com/radical-cybertools/radical.analytics/blob/devel/API.md
* Examples: https://github.com/radical-cybertools/radical.analytics/tree/devel/examples
